==> rustc_1.58.1+dfsg1~ubuntu1.orig.tar.xz: rustc-1.58.1-src/src/tools/clippy/rustc_tools_util/README.md <==
# rustc_tools_util

A small tool to help you generate version information
for packages installed from a git repo

## Usage

Add a `build.rs` file to your repo and list it in `Cargo.toml`
````
build = "build.rs"
````

List rustc_tools_util as regular AND build dependency.
````
[dependencies]
rustc_tools_util = "0.1"

[build-dependencies]
rustc_tools_util = "0.1"
````

In `build.rs`, generate the data in your `main()`
````rust
fn main() {
    println!(
        "cargo:rustc-env=GIT_HASH={}",
        rustc_tools_util::get_commit_hash().unwrap_or_default()
    );
    println!(
        "cargo:rustc-env=COMMIT_DATE={}",
        rustc_tools_util::get_commit_date().unwrap_or_default()
    );
    println!(
        "cargo:rustc-env=RUSTC_RELEASE_CHANNEL={}",
        rustc_tools_util::get_channel().unwrap_or_default()
    );
}

````

Use the version information in your main.rs
````rust
use rustc_tools_util::*;

fn show_version() {
    let version_info = rustc_tools_util::get_version_info!();
    println!("{}", version_info);
}
````
This gives the following output in clippy:
`clippy 0.0.212 (a416c5e 2018-12-14)`


## License

Copyright 2014-2020 The Rust Project Developers

Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
<LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
option. All files in the project carrying such notice may not be
copied, modified, or distributed except according to those terms.

==> rustc-1.76_1.76.0+dfsg0ubuntu1.orig.tar.xz: rustc-1.76.0-src/src/tools/clippy/rustc_tools_util/README.md <==
# rustc_tools_util

A small tool to help you generate version information
for packages installed from a git repo

## Usage

Add a `build.rs` file to your repo and list it in `Cargo.toml`
````toml
build = "build.rs"
````

List rustc_tools_util as regular AND build dependency.
````toml
[dependencies]
rustc_tools_util = "0.3.0"

[build-dependencies]
rustc_tools_util = "0.3.0"
````

In `build.rs`, generate the data in your `main()`

```rust
fn main() {
    rustc_tools_util::setup_version_info!();
}
```

Use the version information in your main.rs

```rust
fn show_version() {
    let version_info = rustc_tools_util::get_version_info!();
    println!("{}", version_info);
}
```

This gives the following output in clippy:
`clippy 0.1.66 (a28f3c8 2022-11-20)`

## Repository

This project is part of the rust-lang/rust-clippy repository. The source code
can be found under `./rustc_tools_util/`.

The changelog for `rustc_tools_util` is available under:
[`rustc_tools_util/CHANGELOG.md`](https://github.com/rust-lang/rust-clippy/blob/master/rustc_tools_util/CHANGELOG.md)

## License

<!-- REUSE-IgnoreStart -->

Copyright 2014-2022 The Rust Project Developers

Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
<LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
option. All files in the project carrying such notice may not be
copied, modified, or distributed except according to those terms.

<!-- REUSE-IgnoreEnd -->
